@@ -143,7 +143,10 @@ typedef enum {
 	kPostDMAEngineInit,
 	kRestartTransport,
 	kRunPollTask,
-	kSetSampleType
+	kSetSampleType,
+	kSetMuteState,
+	kSetAnalogMuteState,										//	[3435307]	
+	kSetDigitalMuteState										//	[3435307]	
 } ActionSelector;
 
 // Machine layout constants. All NewWorld machines have a device-id property
@@ -191,7 +194,8 @@ enum {
 	layoutQ54					=	40,
 	layoutQ59					=	41,
 	layoutNeoBorg_Analog		=	42,
-	layoutNeoBorg_Digital		=	43
+	layoutNeoBorg_Digital		=	43,
+	layoutP73D					=	44
 };
 
 // Hardware type 
@@ -204,6 +208,12 @@ enum{
     kTexas3004HardwareType
 };
 
+//	[3435307]	rbm
+enum {
+	kAnalogAudioSelector			=	'aaud',
+	kDigitalAudioSelector			=	'daud'
+};
+
 // Kind of devices
 enum AudioPortTypes {
     kSndHWInternalSpeaker		=	0x00000001,		// internal speaker present on CPU
@@ -347,7 +357,7 @@ enum speakerIDBitAddresses {
 enum{
     kMaximumPRAMVolume 	= 7,
     kMinimumPRAMVolume	= 0,
-    KNumPramVolumeSteps	= (kMaximumPRAMVolume - kMinimumPRAMVolume + 1),
+    KNumPramVolumeSteps	= (kMaximumPRAMVolume- kMinimumPRAMVolume+1),
     kPRamVolumeAddr		= 8,
     
     kDefaultVolume		= 0x006E006E,
@@ -367,4 +377,26 @@ typedef struct {
 } BiquadInfoList;
 typedef BiquadInfoList * BiquadInfoListPtr;
 
+enum {
+	// Regular, actually addressable streams (i.e. data can be streamed to and/or from these).
+	// As such, these streams can be used with get and set current stream map;
+	// get and set relative volume min, max, and current; and 
+	// get hardware stream map
+	kStreamFrontLeft			= 'fntl',	// front left speaker
+	kStreamFrontRight			= 'fntr',	// front right speaker
+	kStreamSurroundLeft			= 'surl',	// surround left speaker
+	kStreamSurroundRight		= 'surr',	// surround right speaker
+	kStreamCenter				= 'cntr',	// center channel speaker
+	kStreamLFE					= 'lfe ',	// low frequency effects speaker
+	kStreamHeadphoneLeft		= 'hplf',	// left headphone
+	kStreamHeadphoneRight		= 'hprt',	// right headphone
+	kStreamLeftOfCenter			= 'loc ',	//	see usb audio class spec. v1.0, section 3.7.2.3	[in front]
+	kStreamRightOfCenter		= 'roc ',	//	see usb audio class spec. v1.0, section 3.7.2.3	[in front]
+	kStreamSurround				= 'sur ',	//	see usb audio class spec. v1.0, section 3.7.2.3	[rear]
+	kStreamSideLeft				= 'sidl',	//	see usb audio class spec. v1.0, section 3.7.2.3	[left wall]
+	kStreamSideRight			= 'sidr',	//	see usb audio class spec. v1.0, section 3.7.2.3	[right wall]
+	kStreamTop					= 'top ',	//	see usb audio class spec. v1.0, section 3.7.2.3	[overhead]
+	kStreamMono					= 'mono'	//	for usb devices with a spatial configuration of %0000000000000000
+};
+
 #endif
