@@ -12,6 +12,7 @@
 
 #include <IOKit/IOInterruptEventSource.h>
 #include <IOKit/IOUserClient.h>
+#include <IOKit/IOSyncer.h>
 
 #include "AudioHardwareCommon.h"
 #include "AudioHardwareConstants.h"
@@ -32,6 +33,8 @@ enum invokeInternalFunctionSelectors {
 #define kiSubMaxVolume					60
 #define kiSubVolumePercent				92
 
+#define	kAOAPropertyHeadphoneExclusive	'hpex'						/*	Needs to be added to IOAudioTypes.h and then removed from here	*/
+
 typedef struct {
 	UInt32			layoutID;			//	identify the target CPU
 	UInt32			portID;				//	identify port (see: AudioPortTypes in AudioHardwareConstants.h)
@@ -80,7 +83,7 @@ typedef struct AOAStateUserClientStruct {
 	UInt32				ucPramData;
 	UInt32				ucPramVolume;
 	UInt32				ucPowerState;
-	UInt32				ucReserved_3;
+	UInt32				ucLayoutID;
 	UInt32				ucReserved_4;
 	UInt32				ucReserved_5;
 	UInt32				ucReserved_6;
@@ -138,6 +141,7 @@ typedef struct AOAStateUserClientStruct {
 #define kSoftwareDSP					"SoftwareDSP"
 #define kMaxVolumeOffset				"maxVolumeOffset"
 #define kSpeakerID						"SpeakerID"
+#define kMicrophoneID					"MicrophoneID"
 #define kPluginRecoveryOrder			"RecoveryOrder"
 #define kClipRoutines					"ClipRoutines"
 #define kEncoding						"Encoding"
@@ -158,7 +162,9 @@ typedef struct AOAStateUserClientStruct {
 #define kLimiterThreshold				"Threshold"
 #define kLimiterGain					"Gain"
 #define kLimiterRatio					"Ratio"
+#define kLimiterRatioBelow				"RatioBelow"
 #define kLimiterLookahead				"Lookahead"
+#define kLimiterRunInHardware			"RunInHardware"
 
 #define kCrossover						"Crossover"
 #define kCrossoverFrequency				"Frequency"
@@ -248,6 +254,8 @@ protected:
 	bool								mHeadLineDigExclusive;
 	bool								mClockSelectInProcessSemaphore;
 	bool								mSampleRateSelectInProcessSemaphore;
+	OSString *							mInternalSpeakerOutputString;
+	OSString *							mExternalSpeakerOutputString;
 	
 	// we keep the engines around to have a cleaner initHardware
     AppleDBDMAAudio *					mDriverDMAEngine;
@@ -263,6 +271,7 @@ protected:
 	UInt32								mLayoutID;
 	UInt32								mDetectCollection;
 	UInt32								mSpeakerID;
+	UInt32								mMicrophoneID;
 	bool								mCurrentPluginHasSoftwareInputGain;
 	UInt32								mAmpRecoveryMuteDuration;
 	
@@ -278,6 +287,7 @@ protected:
 
     OSArray	*							AudioSoftDSPFeatures;
 	OSString *							mCurrentProcessingOutputString;
+	OSString *							mCurrentProcessingInputString;
 
 	// Dynamic variable that handle the connected devices
     sndHWDeviceSpec						currentDevices;
@@ -296,6 +306,7 @@ protected:
 	IOService *							mProvider;
 	
 	IOAudioSampleRate					mTransportSampleRate;
+	IOSyncer *							mSignal;
 	
 public:
 	// Classical Unix funxtions
@@ -423,6 +434,7 @@ protected:
 	GpioAttributes		getInputDataMuxForConnection (const char * entry);
 
 	void				setSoftwareOutputDSP (const char * inSelectedOutput);
+	void				setSoftwareInputDSP (const char * inSelectedInput);
 
 	UInt32				getMaxVolumeOffsetForOutput (const UInt32 inCode);
 	UInt32				getMaxVolumeOffsetForOutput (const char * inSelectedOutput);
@@ -454,9 +466,7 @@ protected:
 	void				initializeDetectCollection ( void );
 	UInt32				parseOutputDetectCollection (void);
 	UInt32				parseInputDetectCollection (void);
-	void				selectOutput (const UInt32 inSelection, const bool inUpdateAll = TRUE);
-	void				muteAnalogOuts ();
-	void				setAnalogCodecMute (UInt32 inValue);
+	void				selectOutput (const UInt32 inSelection, const bool inMuteState, const bool inUpdateAll = TRUE);
 
 	char *				getConnectionKeyFromCharCode (const SInt32 inSelection, const UInt32 inDirection);
 
