@@ -45,6 +45,7 @@ bool AppleTopazAudio::start (IOService * provider) {
 
 	debug3IOLog ("+AppleTopazAudio[%p]::start(%p)\n", this, provider);
 
+	result = FALSE;
 	FailIf (!provider, Exit);
 	mAudioDeviceProvider = (AppleOnboardAudio *)provider;
 
@@ -203,29 +204,39 @@ void AppleTopazAudio::postDMAEngineInit () {
 }
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-bool AppleTopazAudio::getMute () {
-	return ( mCurMuteState );	
+IOReturn AppleTopazAudio::setCodecMute (bool muteState) {
+	return setMute ( muteState, kDigitalAudioSelector );	//	[3435307]	
 }
 
-//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-IOReturn AppleTopazAudio::setMute (bool muteState) {
+// --------------------------------------------------------------------------
+//	[3435307]	
+IOReturn AppleTopazAudio::setCodecMute (bool muteState, UInt32 streamType) {
 	UInt8			data;
-	IOReturn		result;
+	IOReturn		result = kIOReturnSuccess;
 	
-	result = kIOReturnSuccess;
-	debug2IOLog ( "+ AppleTopazAudio::setMute ( %d )\n", muteState );
+	debug3IOLog("+ AppleTopazAudio::setMute (%d, %4s)\n", muteState, (char*)&streamType);
 
-	data = kCS8420_CODEC == mCodecID ? kMISC_CNTRL_1_INIT_8420 : kMISC_CNTRL_1_INIT_8406 ;
-	data &= ~( 1 << baMuteAES );
-	data |= muteState ? ( muteAES3 << baMuteAES ) : ( normalAES3 << baMuteAES ) ;
-	result = CODEC_WriteRegister ( map_MISC_CNTRL_1, data );
-	FailIf ( kIOReturnSuccess != result, Exit );
-
-	mCurMuteState = muteState;
+	switch ( streamType ) {
+		case kDigitalAudioSelector:
+			data = kCS8420_CODEC == mCodecID ? kMISC_CNTRL_1_INIT_8420 : kMISC_CNTRL_1_INIT_8406 ;
+			data &= ~( 1 << baMuteAES );
+			data |= muteState ? ( muteAES3 << baMuteAES ) : ( normalAES3 << baMuteAES ) ;
+			result = CODEC_WriteRegister ( map_MISC_CNTRL_1, data );
+			break;
+		default:
+			result = kIOReturnError;
+			break;
+	}
 	
-Exit:
-	debug3IOLog ( "-AppleTopazAudio::setMute ( %d ) result %d\n", muteState, result );
-	return ( result );	
+	debug4IOLog("- AppleTopazAudio::setMute (%d, %4s) returns %X\n", muteState, (char*)&streamType, result);
+	return result;
+}
+
+// --------------------------------------------------------------------------
+//	[3435307]	
+bool AppleTopazAudio::hasDigitalMute ()
+{
+	return true;
 }
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -283,7 +294,7 @@ IOReturn AppleTopazAudio::performDeviceWake () {
 
 	//	[3333215]	Codec operation may not be restored after wake from
 	//	sleep so start state machine to recover codec operation.
-	//	[3344893]	Recovery is only implemented if running on the internal 
+	//	[3344893,3352595]	Recovery is only implemented if running on the internal 
 	//	clock source since failure is associated with the sample rate converter 
 	//	and the sample rate converter is not in use when running on the external 
 	//	clock source.
@@ -595,7 +606,7 @@ IOReturn	AppleTopazAudio::makeClockSelect ( UInt32 clockSource ) {
 	//	Unmute the coded output
 	data = mShadowRegs[map_MISC_CNTRL_1];
 	data &= ~( kCS84XX_BIT_MASK << baMuteAES );
-	if ( mCurMuteState ) {
+	if ( mDigitalMuteState ) {
 		data |= ( muteAES3 << baMuteAES );
 	} else {
 		data |= ( normalAES3 << baMuteAES );
@@ -921,6 +932,7 @@ IOReturn AppleTopazAudio::CODEC_IsControlRegister ( UInt8 regAddr ) {
 			switch ( mCodecID ) {
 				case kCS8406_CODEC:					result = kIOReturnError;			break;
 				case kCS8420_CODEC:					result = kIOReturnSuccess;			break;
+				default:							result = kIOReturnError;
 			};
 			break;
 		case map_MISC_CNTRL_1:
@@ -970,6 +982,8 @@ IOReturn AppleTopazAudio::CODEC_IsControlRegister ( UInt8 regAddr ) {
 IOReturn 	AppleTopazAudio::CODEC_IsStatusRegister ( UInt8 regAddr ) {
 	IOReturn	result;
 	
+	result = kIOReturnError;
+	
 	switch ( regAddr ) {
 		case map_IRQ1_STATUS:
 		case map_IRQ2_STATUS:
@@ -1010,9 +1024,10 @@ IOReturn 	AppleTopazAudio::CODEC_ReadRegister ( UInt8 regAddr, UInt8 * registerD
 	UInt32			index;
 	UInt32			codecRegSize;
 
+	result = kIOReturnError;
+	success = false;
 	FailIf ( NULL == mPlatformInterface, Exit );
 	result = kIOReturnSuccess;
-	success = false;
 	if ( 1 < size ) { regAddr |= (UInt8)kMAP_AUTO_INCREMENT_ENABLE; }
 	
 	if ( kIOReturnSuccess == CODEC_GetRegSize ( regAddr, &codecRegSize ) ) {
@@ -1142,8 +1157,8 @@ IOReturn 	AppleTopazAudio::CODEC_WriteRegister ( UInt8 regAddr, UInt8 registerDa
 	Boolean			updateRequired;
 	bool			success = true;
 
-	FailIf ( NULL == mPlatformInterface, Exit );
 	result = kIOReturnError;
+	FailIf ( NULL == mPlatformInterface, Exit );
 	updateRequired = false;
 
 #ifdef kVERBOSE_LOG
