@@ -50,6 +50,9 @@ const UInt32 KeyLargoPlatform::kI2S1InterfaceEnable 		= ( 1 << kI2S1Enable );
 
 const char*  KeyLargoPlatform::kAmpMuteEntry				= "amp-mute";
 const char*  KeyLargoPlatform::kAnalogHWResetEntry			= "audio-hw-reset";
+
+const char*	 KeyLargoPlatform::kCodecErrorIrqTypeEntry		= "codec-error-irq";
+const char*	 KeyLargoPlatform::kCodecIrqTypeEntry			= "codec-irq";
 const char*	 KeyLargoPlatform::kComboInJackTypeEntry		= "combo-input-type";
 const char*	 KeyLargoPlatform::kComboOutJackTypeEntry		= "combo-output-type";
 const char*  KeyLargoPlatform::kDigitalHWResetEntry			= "audio-dig-hw-reset";
@@ -139,22 +142,22 @@ bool KeyLargoPlatform::init (IOService* device, AppleOnboardAudio* provider, UIn
 	}
 	debug2IOLog ("KeyLargoPlatform - mI2CPort = %ld\n", mI2CPort);
 
-	initAudioGpioPtr ( gpio, kAmpMuteEntry, &mAmplifierMuteGpio, &mAmplifierMuteActiveState );						//	control - no interrupt
-	initAudioGpioPtr ( gpio, kAnalogHWResetEntry, &mAnalogResetGpio, &mAnalogResetActiveState );					//	control - no interrupt
-	initAudioGpioPtr ( gpio, kComboInJackTypeEntry, &mComboInJackTypeGpio, &mComboInJackTypeActiveState );			//	control - no interrupt
-	initAudioGpioPtr ( gpio, kComboOutJackTypeEntry, &mComboOutJackTypeGpio, &mComboOutJackTypeActiveState );		//	control - no interrupt
-	initAudioGpioPtr ( gpio, kDigitalHWResetEntry, &mDigitalResetGpio, &mDigitalResetActiveState );					//	control - no interrupt
-	initAudioGpioPtr ( gpio, kDigitalInDetectEntry, &mDigitalInDetectGpio, &mDigitalInDetectActiveState );			//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kDigitalInDetectEntry, &mCodecErrorInterruptGpio, &mCodecErrorInterruptActiveState );	//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kDigitalInDetectEntry, &mCodecInterruptGpio, &mCodecInterruptActiveState );			//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kDigitalOutDetectEntry, &mDigitalOutDetectGpio, &mDigitalOutDetectActiveState );		//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kHeadphoneDetectInt, &mHeadphoneDetectGpio, &mHeadphoneDetectActiveState );			//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kHeadphoneMuteEntry, &mHeadphoneMuteGpio, &mHeadphoneMuteActiveState );				//	control - no interrupt
-	initAudioGpioPtr ( gpio, kInternalSpeakerIDEntry, &mInternalSpeakerIDGpio, &mInternalSpeakerIDActiveState );	//	control - no interrupt
-	initAudioGpioPtr ( gpio, kLineInDetectInt, &mLineInDetectGpio, &mLineInDetectActiveState );						//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kLineOutDetectInt, &mLineOutDetectGpio, &mLineOutDetectActiveState );					//	detect  - does interrupt	
-	initAudioGpioPtr ( gpio, kLineOutMuteEntry, &mLineOutMuteGpio, &mLineOutMuteActiveState );						//	control - no interrupt
-	initAudioGpioPtr ( gpio, kSpeakerDetectEntry, &mSpeakerDetectGpio, &mSpeakerDetectActiveState );				//	detect  - does interrupt	
+	initAudioGpioPtr ( gpio, kAmpMuteEntry, &mAmplifierMuteGpio, &mAmplifierMuteActiveState, NULL );											//	control - no interrupt
+	initAudioGpioPtr ( gpio, kAnalogHWResetEntry, &mAnalogResetGpio, &mAnalogResetActiveState, NULL );											//	control - no interrupt
+	initAudioGpioPtr ( gpio, kCodecErrorIrqTypeEntry, &mCodecErrorInterruptGpio, &mCodecErrorInterruptActiveState, &mCodecErrorIntProvider );	//	control - does interrupt
+	initAudioGpioPtr ( gpio, kCodecIrqTypeEntry, &mCodecInterruptGpio, &mCodecInterruptActiveState, &mCodecIntProvider );						//	control - does interrupt
+	initAudioGpioPtr ( gpio, kComboInJackTypeEntry, &mComboInJackTypeGpio, &mComboInJackTypeActiveState, NULL );								//	control - no interrupt
+	initAudioGpioPtr ( gpio, kComboOutJackTypeEntry, &mComboOutJackTypeGpio, &mComboOutJackTypeActiveState, NULL );								//	control - no interrupt
+	initAudioGpioPtr ( gpio, kDigitalHWResetEntry, &mDigitalResetGpio, &mDigitalResetActiveState, NULL );										//	control - no interrupt
+	initAudioGpioPtr ( gpio, kDigitalInDetectEntry, &mDigitalInDetectGpio, &mDigitalInDetectActiveState, &mDigitalInDetectIntProvider );		//	detect  - does interrupt
+	initAudioGpioPtr ( gpio, kDigitalOutDetectEntry, &mDigitalOutDetectGpio, &mDigitalOutDetectActiveState, &mDigitalOutDetectIntProvider );	//	detect  - does interrupt
+	initAudioGpioPtr ( gpio, kHeadphoneDetectInt, &mHeadphoneDetectGpio, &mHeadphoneDetectActiveState, &mHeadphoneDetectIntProvider );			//	detect  - does interrupt
+	initAudioGpioPtr ( gpio, kHeadphoneMuteEntry, &mHeadphoneMuteGpio, &mHeadphoneMuteActiveState, NULL );										//	control - no interrupt
+	initAudioGpioPtr ( gpio, kInternalSpeakerIDEntry, &mInternalSpeakerIDGpio, &mInternalSpeakerIDActiveState, NULL );							//	control - no interrupt
+	initAudioGpioPtr ( gpio, kLineInDetectInt, &mLineInDetectGpio, &mLineInDetectActiveState, &mDigitalInDetectIntProvider );					//	detect  - does interrupt
+	initAudioGpioPtr ( gpio, kLineOutDetectInt, &mLineOutDetectGpio, &mLineOutDetectActiveState, &mLineOutDetectIntProvider );					//	detect  - does interrupt
+	initAudioGpioPtr ( gpio, kLineOutMuteEntry, &mLineOutMuteGpio, &mLineOutMuteActiveState, NULL );											//	control - no interrupt
+	initAudioGpioPtr ( gpio, kSpeakerDetectEntry, &mSpeakerDetectGpio, &mSpeakerDetectActiveState, &mSpeakerDetectIntProvider );				//	detect  - does interrupt
 
 	theService = (OSDynamicCast(IOService, i2s));
 	FailWithAction (!theService, result = false, Exit);
@@ -188,6 +191,20 @@ void KeyLargoPlatform::free() {
 	debugIOLog ("- KeyLargoPlatform::free()\n");
 }
 
+//	--------------------------------------------------------------------------------
+IOReturn KeyLargoPlatform::performPlatformSleep ( void ) {
+	unregisterInterrupts();
+	return kIOReturnSuccess;
+}
+
+
+//	--------------------------------------------------------------------------------
+IOReturn KeyLargoPlatform::performPlatformWake ( IOService * device ) {
+	registerInterrupts ( device );
+	return kIOReturnSuccess;
+}
+
+
 #pragma mark ---------------------------
 #pragma mark  Codec Methods	
 #pragma mark ---------------------------
@@ -495,6 +512,34 @@ UInt32 KeyLargoPlatform::getI2SIOMIntControl () {
 	return result;
 }
 
+//	--------------------------------------------------------------------------------
+IOReturn KeyLargoPlatform::setPeakLevel ( UInt32 channelTarget, UInt32 levelMeterValue ) {
+	IOReturn		result = kIOReturnSuccess;
+	
+	debug3IOLog ( "+ KeyLargoPlatform::setPeakLevel ( '%4s', %lX )\n", (char*)&channelTarget, levelMeterValue );
+	switch ( channelTarget ) {
+		case kStreamFrontLeft:		OSWriteLittleInt32 ( mI2SBaseAddress, kI2SPeakLevelIn0Offset, levelMeterValue );		break;
+		case kStreamFrontRight:		OSWriteLittleInt32 ( mI2SBaseAddress, kI2SPeakLevelIn1Offset, levelMeterValue );		break;
+		default:					result = kIOReturnBadArgument;															break;
+	}
+	debug4IOLog ( "- KeyLargoPlatform::setPeakLevel ( '%4s', %lX ) returns %X\n", (char*)&channelTarget, levelMeterValue, result );
+	return result;
+}
+
+//	--------------------------------------------------------------------------------
+UInt32 KeyLargoPlatform::getPeakLevel ( UInt32 channelTarget ) {
+	UInt32			result;
+	
+	debug2IOLog ( "+ KeyLargoPlatform::getPeakLevel ( '%4s' )\n", (char*)&channelTarget );
+	switch ( channelTarget ) {
+		case kStreamFrontLeft:		result = OSReadLittleInt32 ( mI2SBaseAddress, kI2SPeakLevelIn0Offset );		break;
+		case kStreamFrontRight:		result = OSReadLittleInt32 ( mI2SBaseAddress, kI2SPeakLevelIn1Offset );		break;
+		default:					result = 0;																	break;
+	}
+	debug3IOLog ( "- KeyLargoPlatform::getPeakLevel ( '%4s' ) returns %lX\n", (char*)&channelTarget, result );
+	return result;
+}
+
 //	--------------------------------------------------------------------------------
 IOReturn KeyLargoPlatform::releaseI2SClockSource(I2SClockFrequency inFrequency)	
 {
@@ -577,19 +622,14 @@ IOReturn KeyLargoPlatform::requestI2SClockSource(I2SClockFrequency inFrequency)
 }
 
 //	--------------------------------------------------------------------------------
-IOReturn KeyLargoPlatform::setFrameCount (UInt32 value) {
-	OSWriteLittleInt32(mI2SBaseAddress, kI2SFrameCountOffset, value);
-
+IOReturn KeyLargoPlatform::setFrameCount ( UInt32 value ) {
+	OSWriteLittleInt32 ( mI2SBaseAddress, kI2SFrameCountOffset, value );
 	return kIOReturnSuccess;
 }
 
 //	--------------------------------------------------------------------------------
 UInt32 KeyLargoPlatform::getFrameCount () {
-	UInt32 frameCount = 0;
-
 	return OSReadLittleInt32(mI2SBaseAddress, kI2SFrameCountOffset);
-
-	return frameCount;
 }
 
 #pragma mark ---------------------------
@@ -597,7 +637,7 @@ UInt32 KeyLargoPlatform::getFrameCount () {
 #pragma mark ---------------------------
 
 //	--------------------------------------------------------------------------------
-void KeyLargoPlatform::initAudioGpioPtr ( const IORegistryEntry * start, const char * gpioName, GpioPtr* gpioH, GpioActiveState* gpioActiveStatePtr ) {
+void KeyLargoPlatform::initAudioGpioPtr ( const IORegistryEntry * start, const char * gpioName, GpioPtr* gpioH, GpioActiveState* gpioActiveStatePtr, IOService ** intProvider ) {
     IORegistryEntry			*theRegEntry;
 	OSData					*theProperty;
 	IOMemoryMap				*map;
@@ -607,6 +647,9 @@ void KeyLargoPlatform::initAudioGpioPtr ( const IORegistryEntry * start, const c
 	
 	theRegEntry = FindEntryByProperty (start, kAudioGPIO, gpioName);
 	if ( NULL != theRegEntry ) {
+		if ( NULL != intProvider ) {
+			*intProvider = OSDynamicCast ( IOService, theRegEntry );
+		}
 		theProperty = OSDynamicCast ( OSData, theRegEntry->getProperty ( kAAPLAddress ) );
 		if ( NULL != theProperty ) {
 			theGpioAddr = (UInt32*)theProperty->getBytesNoCopy();
@@ -716,6 +759,7 @@ GpioAttributes KeyLargoPlatform::getGpioAttributes ( GPIOSelector theGpio ) {
 			case kGPIO_Selector_LineInDetect:
 			case kGPIO_Selector_LineOutDetect:
 			case kGPIO_Selector_SpeakerDetect:
+				if ( kGPIO_Selector_HeadphoneDetect == theGpio ) { *gpioPtr |= 0x80; }	//	BROWN PATCH - TEMPORARY!!!
 				if ( ( gpioValue & ( gpioBIT_MASK << gpioPIN_RO ) ) == ( activeState << gpioPIN_RO ) ) {
 					result = kGPIO_Connected;
 				} else {
@@ -900,7 +944,7 @@ GpioAttributes	KeyLargoPlatform::getSpeakerConnected() {
 
 //	--------------------------------------------------------------------------------
 GpioAttributes KeyLargoPlatform::getSpeakerMuteState() {
-	return getGpioAttributes ( kGPIO_Selector_SpeakerDetect );
+	return getGpioAttributes ( kGPIO_Selector_SpeakerMute );
 }
 
 //	--------------------------------------------------------------------------------
@@ -912,7 +956,6 @@ IOReturn KeyLargoPlatform::setSpeakerMuteState ( GpioAttributes muteState ) {
 IOReturn KeyLargoPlatform::setCodecReset ( CODEC_RESET target, GpioAttributes reset ) {
 	IOReturn		result = kIOReturnError;
 	
-	debug3IOLog ( "+ KeyLargoPlatform::setCodecReset ( 0x%x, %d )\n", target, reset );
 	if ( kCODEC_RESET_Analog == target ) {
 		if ( NULL != mAnalogResetGpio ) {
 			result = setGpioAttributes ( kGPIO_Selector_AnalogCodecReset, reset );
@@ -922,7 +965,6 @@ IOReturn KeyLargoPlatform::setCodecReset ( CODEC_RESET target, GpioAttributes re
 			result = setGpioAttributes ( kGPIO_Selector_DigitalCodecReset, reset );
 		}
 	}
-	debug3IOLog ( "- KeyLargoPlatform::setCodecReset ( %d ) result = %X\n", reset, result );
 	return result;
 }
 
@@ -967,6 +1009,7 @@ IOReturn KeyLargoPlatform::registerInterruptHandler (IOService * theDevice, void
 	return result;
 }
 
+//	--------------------------------------------------------------------------------
 IOReturn KeyLargoPlatform::unregisterInterruptHandler (IOService * theDevice, void * interruptHandler, PlatformInterruptSource source ) {
 	IOReturn				result;
 
@@ -1017,7 +1060,6 @@ Exit:
 	if (NULL != theInterruptEventSource) {
 		theInterruptEventSource->release();
 	}
-	debug2IOLog ( "KeyLargoPlatform::setHeadphoneDetectInterruptHandler() returns %X\n", result );
 	return result;
 }
 
@@ -1235,13 +1277,13 @@ Exit:
 
 //	--------------------------------------------------------------------------------
 void KeyLargoPlatform::logFCR1( void ) {
-	debug2IOLog ( "logFCR1 = %lX\n", OSReadLittleInt32 ( mIOConfigurationBaseAddress, kFCR1Offset ) );
+	debug2IOLog ( "logFCR1 = %X\n", OSReadLittleInt32 ( mIOConfigurationBaseAddress, kFCR1Offset ) );
 	return;
 }
 
 //	--------------------------------------------------------------------------------
 void KeyLargoPlatform::logFCR3( void ) {
-	debug2IOLog ( "logFCR3 = %lX\n", OSReadLittleInt32 ( mIOConfigurationBaseAddress, kFCR3Offset ) );
+	debug2IOLog ( "logFCR3 = %X\n", OSReadLittleInt32 ( mIOConfigurationBaseAddress, kFCR3Offset ) );
 	return;
 }
 
@@ -1263,7 +1305,6 @@ IOReturn KeyLargoPlatform::gpioWrite( UInt8* gpioAddress, UInt8 data ) {
 
 		*gpioAddress = gpioData;
 		result = kIOReturnSuccess;
-		debug4IOLog( "KeyLargoPlatform::gpioWrite( 0x%8.0X, 0x%2.0X ), *gpioAddress 0x%2.0X\n", (unsigned int)gpioAddress, gpioData, *gpioAddress );
 	}
 	return result;
 }
@@ -1344,6 +1385,7 @@ IOReturn KeyLargoPlatform::initI2S(IOMemoryMap* map) {
     {
         DEBUG_IOLOG("AudioI2SControl::init ERROR: unable to setup ioBaseAddress and i2SInterfaceNumber\n");
     }
+	debug4IOLog ( "mIOBaseAddress %p, mIOBaseAddressMemory %p, mI2SInterfaceNumber %d\n", mIOBaseAddress, mIOBaseAddressMemory, mI2SInterfaceNumber );
 	FailIf (NULL == mIOBaseAddressMemory, Exit);
 
 	//	[3060321]	ioConfigurationBaseAddress is required by this object in order to enable the target
@@ -1389,21 +1431,11 @@ IOReturn KeyLargoPlatform::initI2S(IOMemoryMap* map) {
 	//
 	
 	//	Map the I2S configuration registers
-	if (kUseI2SCell0 == mI2SInterfaceNumber) {
-		mIOI2SBaseAddressMemory = IODeviceMemory::withRange ((IOPhysicalAddress)((UInt8 *)mSoundConfigSpace), kI2S_IO_CONFIGURATION_SIZE);
-	} else {
-		mIOI2SBaseAddressMemory = IODeviceMemory::withRange ((IOPhysicalAddress)((UInt8 *)mSoundConfigSpace), kI2S_IO_CONFIGURATION_SIZE);
-	}
-	if (NULL != mIOI2SBaseAddressMemory) {
-		mI2SBaseAddress = (void *)mIOI2SBaseAddressMemory->map()->getVirtualAddress();
-	} else {
-		return kIOReturnError;
-	}
-	FailIf (NULL == mIOI2SBaseAddressMemory, Exit)
-	
+	mIOI2SBaseAddressMemory = IODeviceMemory::withRange ((IOPhysicalAddress)((UInt8 *)mSoundConfigSpace), kI2S_IO_CONFIGURATION_SIZE);
+	FailIf ( NULL == mIOI2SBaseAddressMemory, Exit );
 	mI2SBaseAddress = (void *)mIOI2SBaseAddressMemory->map()->getVirtualAddress();
 	FailIf (NULL == mI2SBaseAddress, Exit);
-
+	
 	debug2IOLog ("KeyLargoPlatform::initI2S - mI2SInterfaceNumber = 0x%X\n", mI2SInterfaceNumber);
 	debug2IOLog ("KeyLargoPlatform::initI2S - mIOI2SBaseAddressMemory = %p\n", mIOI2SBaseAddressMemory);
 	debug2IOLog ("KeyLargoPlatform::initI2S - mI2SBaseAddress = %p\n", mI2SBaseAddress);
@@ -1574,8 +1606,10 @@ IOReturn	KeyLargoPlatform::getPlatformState ( PlatformStateStructPtr outState )
 	outState->i2s.frameCountToMatch = 0;
 	outState->i2s.dataWordSizes = getDataWordSizes ();
 	outState->i2s.peakLevelSfSel = 0;
-	outState->i2s.peakLevelIn0 = 0;
-	outState->i2s.peakLevelIn1 = 0;
+	outState->i2s.peakLevelIn0 = getPeakLevel ( kStreamFrontLeft );
+	outState->i2s.peakLevelIn1 = getPeakLevel ( kStreamFrontRight );
+	outState->i2s.newPeakLevelIn0 = 0;			/*	always 0 - triggers update on setPlatformState!		*/
+	outState->i2s.newPeakLevelIn1 = 0;			/*	always 0 - triggers update on setPlatformState!		*/
 	
 	outState->fcr.i2sEnable = getI2SEnable ();
 	outState->fcr.i2sClockEnable = getI2SClockEnable ();
@@ -1633,54 +1667,89 @@ Exit:
 IOReturn	KeyLargoPlatform::setPlatformState ( PlatformStateStructPtr inState ) {
 	IOReturn			result = kIOReturnBadArgument;
 	
+	debug2IOLog ( "+ UC KeyLargoPlatform::setPlatformState ( %p )\n", inState );
 	debug2IOLog ( "+ UC KeyLargoPlatform::setPlatformState ( %p )\n", inState );
 	FailIf ( NULL == inState, Exit );
-	result = setI2SIOMIntControl ( inState->i2s.intCtrl );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	result = setSerialFormatRegister ( inState->i2s.serialFmt );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	result = setFrameCount ( inState->i2s.frameCount );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	result = setDataWordSizes ( inState->i2s.dataWordSizes );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	
-	result = setI2SEnable ( inState->fcr.i2sEnable );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	result = setI2SClockEnable ( inState->fcr.i2sClockEnable );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	result = setI2SCellEnable ( inState->fcr.i2sCellEnable );
-	FailIf ( kIOReturnSuccess != result, Exit );
-	
+	if ( inState->i2s.intCtrl != getI2SIOMIntControl () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setI2SIOMIntControl ( %lX )\n", inState->i2s.intCtrl );
+		result = setI2SIOMIntControl ( inState->i2s.intCtrl );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( inState->i2s.serialFmt != getSerialFormatRegister () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setSerialFormatRegister ( %lX )\n", inState->i2s.serialFmt );
+		result = setSerialFormatRegister ( inState->i2s.serialFmt );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( ( inState->i2s.frameCount != getFrameCount () ) && ( 0 == inState->i2s.frameCount ) ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setFrameCount ( %lX )\n", inState->i2s.frameCount );
+		result = setFrameCount ( inState->i2s.frameCount );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( inState->i2s.dataWordSizes != getDataWordSizes () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setDataWordSizes ( %lX )\n", inState->i2s.dataWordSizes );
+		result = setDataWordSizes ( inState->i2s.dataWordSizes );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( 0 != inState->i2s.newPeakLevelIn0 ) {
+		debug2IOLog ( "KeyLargoPlatform::setPeakLevel ( kStreamFrontLeft, %lX )\n", inState->i2s.peakLevelIn0 );
+		setPeakLevel ( kStreamFrontLeft, inState->i2s.peakLevelIn0 );
+	}
+	if ( 0 != inState->i2s.newPeakLevelIn1 ) {
+		debug2IOLog ( "KeyLargoPlatform::setPeakLevel ( kStreamFrontRight, %lX )\n", inState->i2s.peakLevelIn1 );
+		setPeakLevel ( kStreamFrontRight, inState->i2s.peakLevelIn1 );
+	}
+	if ( inState->fcr.i2sEnable != getI2SEnable () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setI2SEnable ( %lX )\n", inState->fcr.i2sEnable );
+		result = setI2SEnable ( inState->fcr.i2sEnable );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( inState->fcr.i2sClockEnable != getI2SClockEnable () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setI2SClockEnable ( %lX )\n", inState->fcr.i2sClockEnable );
+		result = setI2SClockEnable ( inState->fcr.i2sClockEnable );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
+	if ( inState->fcr.i2sCellEnable != getI2SCellEnable () ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setI2SCellEnable ( %lX )\n", inState->fcr.i2sCellEnable );
+		result = setI2SCellEnable ( inState->fcr.i2sCellEnable );
+		FailIf ( kIOReturnSuccess != result, Exit );
+	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_AnalogCodecReset ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setCodecReset ( kCODEC_RESET_Analog, %X )\n", inState->gpio.gpio_AnalogCodecReset );
 		result = setCodecReset ( kCODEC_RESET_Analog, inState->gpio.gpio_AnalogCodecReset );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_ClockMux ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setClockMux ( %X )\n", inState->gpio.gpio_ClockMux );
 		result = setClockMux ( inState->gpio.gpio_ClockMux );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_DigitalCodecReset ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setCodecReset ( kCODEC_RESET_Digital, %X )\n", inState->gpio.gpio_DigitalCodecReset );
 		result = setCodecReset ( kCODEC_RESET_Digital, inState->gpio.gpio_DigitalCodecReset );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_HeadphoneMute ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setHeadphoneMuteState ( %X )\n", inState->gpio.gpio_HeadphoneMute );
 		result = setHeadphoneMuteState ( inState->gpio.gpio_HeadphoneMute );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_InputDataMux ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setInputDataMux ( %X )\n", inState->gpio.gpio_InputDataMux );
 		result = setInputDataMux ( inState->gpio.gpio_InputDataMux );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_LineOutMute ) {
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setLineOutMuteState ( %X )\n", inState->gpio.gpio_LineOutMute );
 		result = setLineOutMuteState ( inState->gpio.gpio_LineOutMute );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 	if ( kGPIO_Unknown != inState->gpio.gpio_SpeakerMute ) {
-		IOLog ( "K2Platform::setPlatformState sets inState->gpio.gpio_SpeakerMute %d\n", inState->gpio.gpio_SpeakerMute );
+		debug2IOLog ( "KeyLargoPlatform::setPlatformState setSpeakerMuteState ( %X )\n", inState->gpio.gpio_SpeakerMute );
 		result = setSpeakerMuteState ( inState->gpio.gpio_SpeakerMute );
 		FailIf ( kIOReturnSuccess != result, Exit );
 	}
 Exit:
+	debug3IOLog ( "- UC KeyLargoPlatform::setPlatformState ( %p ) returns %X\n", inState, result );
 	debug3IOLog ( "- UC KeyLargoPlatform::setPlatformState ( %p ) returns %X\n", inState, result );
 	return result;
 }
